@@ -359,6 +359,52 @@ todo_fams <- function(args) {
     args
 }
 
+todo_fams_presel <- function(args) {
+    # shrink familyset based on Kendall's tau and asymmetry index
+    if (args$emp_tau > 0) {
+        # calculate asymetry indices
+        x <- qnorm(cbind(args$u1, args$u2))
+        c11 <- cor(x[(x[, 1] > 0) & (x[, 2] > 0), ])[1, 2]
+        c00 <- cor(x[(x[, 1] < 0) & (x[, 2] < 0), ])[1, 2]
+        if (c11 - c00 > 0.3) {
+            todo <- c(0, 2, fams11)
+        } else if (c11 - c00 > 0.05) {
+            todo <- c(0, 1, 2, 5, 20, fams11)
+        } else if (c11 - c00 < -0.3) {
+            todo <- c(0, 2, fams00)
+        } else if (c11 - c00 < -0.05) {
+            todo <- c(0, 1, 2, 5, 10, fams00)
+        } else {
+            todo <- c(0, posfams)
+        }
+    } else if (args$emp_tau < 0) {
+        # calculate asymetry indices
+        x <- qnorm(cbind(args$u1, args$u2))
+        c10 <- cor(x[(x[, 1] > 0) & (x[, 2] < 0), ])[1, 2]
+        c01 <- cor(x[(x[, 1] < 0) & (x[, 2] > 0), ])[1, 2]
+        if (c10 - c01 < -0.3) {
+            todo <- c(0, 2, fams10)
+        } else if (c10 - c01 < -0.05) {
+            todo <- c(0, 1, 2, 5, 30, fams10)
+        } else if (c10 - c01 > 0.3) {
+            todo <- c(0, 2, fams01)
+        } else if (c10 - c01 > 0.05) {
+            todo <- c(0, 1, 2, 5, 40, fams01)
+        } else {
+            todo <- c(0, negfams)
+        }
+    } else {
+        todo <- allfams
+    }
+
+    # restrict to familie
+    tmpfams <- todo[which(todo %in% args$familyset)]
+    # check if any family is feasible; if not, keep all
+    if (length(tmpfams) > 1)
+        args$familyset <- tmpfams
+    args
+}
+
 ## check max.BB and max.df specifications
 check_est_pars <- function(args) {
     if (!is.null(args$max.df)) {
@@ -451,7 +497,7 @@ check_est_pars <- function(args) {
                  "Estimation method has to be either 'mle' or 'itau'.",
                  call. = FALSE)
         if (!is.null(args$family)) {
-            if ((args$method == "itau") && (!(args$family %in% c(0, allfams[onepar])))) {
+            if ((args$method == "itau") && (!(args$family %in% c(0, 2, allfams[onepar])))) {
                 warning(" In ", args$call[1], ": ",
                         "For two parameter copulas the estimation method 'itau' cannot ",
                         "be used. The method is automatically set to 'mle'.",
@@ -460,7 +506,7 @@ check_est_pars <- function(args) {
             }
         }
         if (!is.null(args$familyset)) {
-            if ((args$method == "itau") && (!all(args$familyset %in% c(0, allfams[onepar])))) {
+            if ((args$method == "itau") && (!all(args$familyset %in% c(0, 2, allfams[onepar])))) {
                 warning(" In ", args$call[1], ": ",
                         "For two parameter copulas the estimation method 'itau' cannot ",
                         "be used. The method is automatically set to 'mle'.",
@@ -486,6 +532,23 @@ check_est_pars <- function(args) {
     args
 }
 
+check_twoparams <- function(args) {
+    if (!is.null(args$familyset)) {
+        if ((args$method == "itau") &&
+            (!all(args$familyset %in% c(0, 2, allfams[onepar])))) {
+            warning(' In ', args$call[1], ': ',
+                    'Two parameter families (other than the t-copula) cannot',
+                    ' be handled by method "itau".',
+                    ' They are automatically removed from the familyset.',
+                    call. = FALSE)
+            args$familyset <- args$familyset[args$familyset %in%
+                                                 c(0, 2, allfams[onepar])]
+        }
+    }
+
+    args
+}
+
 check_data <- function(args) {
     if (is.symbol(args$data))
         stop("\n In ", args$call[1], ": ",
