@@ -1343,11 +1343,8 @@ void copLik(int* family, int* n, double* u, double* v, double* theta, double* nu
 
 
 
-/////////////////////////////////////////////////////////////
-// log likelihood einzeln (f?r Jakobs EM algo)
-//
-/////////////////////////////////////////////////////////////
 
+//// log likelihood for each observation --------
 // unvectorized version
 void LL_mod_seperate(int* family, int* n, double* u, double* v, double* theta, double* nu, double* loglik)
 {
@@ -1365,3 +1362,24 @@ void LL_mod_seperate_vec(int* family, int* n, double* u, double* v, double* thet
         LL_mod2(&family[i],&nn,&u[i],&v[i],&theta[i],&nu[i],&loglik[i]);
     };
 }
+
+//// density for each observation --------
+// unvectorized version
+void PDF_seperate(int* family, int* n, double* u, double* v, double* theta, double* nu, double* loglik)
+{
+    int kk=1;
+    for(int i=0; i<(*n); i++){
+        LL_mod2(family,&kk,&u[i],&v[i],theta,nu,&loglik[i]);
+        loglik[i] = exp(loglik[i]);
+    };
+}
+
+// vectorized version
+void PDF_seperate_vec(int* family, int* n, double* u, double* v, double* theta, double* nu, double* loglik)
+{
+    int nn=1;
+    for(int i=0; i<(*n); i++){
+        LL_mod2(&family[i],&nn,&u[i],&v[i],&theta[i],&nu[i],&loglik[i]);
+        loglik[i] = exp(loglik[i]);
+    };
+}
